@@ -14,6 +14,12 @@ fn no_duplicate_extensions() {
         // The "Ruby Haml" syntax also comes with a '.sass' extension. However, we make sure
         // that 'sass' is mapped to the 'Sass' syntax.
         "sass",
+        // The '.fs' extension appears in F# and GLSL.
+        // We default to F#.
+        "fs",
+        // SystemVerilog and Verilog both use .v files.
+        // We default to Verilog.
+        "v",
     ];
 
     let assets = HighlightingAssets::from_binary();
